@@ -16,7 +16,6 @@
 Code related to interfacing with a Neural Network in the DeepSparse Engine using python
 """
 
-import os
 import time
 from enum import Enum
 from typing import Dict, Iterable, List, Optional, Tuple, Union
@@ -61,7 +60,7 @@ __all__ = [
 
 
 ARCH = cpu_architecture()
-NUM_CORES = ARCH.num_physical_cores
+NUM_CORES = ARCH.num_available_physical_cores
 AVX_TYPE = ARCH.isa
 VNNI = ARCH.vnni
 
@@ -167,12 +166,13 @@ class Engine(object):
         self._batch_size = _validate_batch_size(batch_size)
         self._num_cores = _validate_num_cores(num_cores)
         self._scheduler = _validate_scheduler(scheduler)
+        self._input_shapes = input_shapes
         self._cpu_avx_type = AVX_TYPE
         self._cpu_vnni = VNNI
 
-        if input_shapes:
+        if self._input_shapes:
             with override_onnx_input_shapes(
-                self._model_path, input_shapes
+                self._model_path, self._input_shapes
             ) as model_path:
                 self._eng_net = LIB.deepsparse_engine(
                     model_path,
@@ -317,7 +317,7 @@ class Engine(object):
         return self._eng_net.execute_list_out(inp)
 
     def timed_run(
-        self, inp: List[numpy.ndarray], val_inp: bool = True
+        self, inp: List[numpy.ndarray], val_inp: bool = False
     ) -> Tuple[List[numpy.ndarray], float]:
         """
         Convenience method for timing a model inference run.
@@ -512,12 +512,12 @@ class Engine(object):
 
     def _properties_dict(self) -> Dict:
         return {
-            "onnx_file_path": self._model_path,
-            "batch_size": self._batch_size,
-            "num_cores": self._num_cores,
-            "scheduler": self._scheduler,
-            "cpu_avx_type": self._cpu_avx_type,
-            "cpu_vnni": self._cpu_vnni,
+            "onnx_file_path": self.model_path,
+            "batch_size": self.batch_size,
+            "num_cores": self.num_cores,
+            "scheduler": self.scheduler,
+            "cpu_avx_type": self.cpu_avx_type,
+            "cpu_vnni": self.cpu_vnni,
         }
 
 
@@ -565,6 +565,7 @@ def benchmark_model(
     include_outputs: bool = False,
     show_progress: bool = False,
     scheduler: Scheduler = None,
+    input_shapes: List[List[int]] = None,
 ) -> BenchmarkResults:
     """
     Convenience function to benchmark a model in the DeepSparse Engine
@@ -602,6 +603,7 @@ def benchmark_model(
         batch_size=batch_size,
         num_cores=num_cores,
         scheduler=scheduler,
+        input_shapes=input_shapes,
     )
 
     return model.benchmark(
@@ -625,6 +627,7 @@ def analyze_model(
     imposed_as: Optional[float] = None,
     imposed_ks: Optional[float] = None,
     scheduler: Scheduler = None,
+    input_shapes: List[List[int]] = None,
 ) -> dict:
     """
     Function to analyze a model's performance in the DeepSparse Engine.
@@ -660,13 +663,15 @@ def analyze_model(
     :param scheduler: The kind of scheduler to execute with. Pass None for the default.
     :return: the analysis structure containing the performance details of each layer
     """
-    model = model_to_path(model)
-    num_cores = _validate_num_cores(num_cores)
-    batch_size = _validate_batch_size(batch_size)
-    scheduler = _validate_scheduler(scheduler)
-    eng_net = LIB.deepsparse_engine(model, batch_size, num_cores, scheduler.value)
+    model = compile_model(
+        model=model,
+        batch_size=batch_size,
+        num_cores=num_cores,
+        scheduler=scheduler,
+        input_shapes=input_shapes,
+    )
 
-    return eng_net.benchmark(
+    return model._eng_net.benchmark(
         inp,
         num_iterations,
         num_warmup_iterations,
